# Python Narrative packages
- [politicsnlp](https://pypi.org/project/politicsnlp/) for Politics
- [religionnlp](https://pypi.org/project/religionnlp/) for Religion
- [lawnlp](https://pypi.org/project/lawnlp/) for Law
- [economynlp](https://pypi.org/project/economynlp/) for Economy
- [cpanlp](https://pypi.org/project/cpanlp/) for Business
- [militarynlp](https://pypi.org/project/militarynlp/) for Military

## Communicate effectively within a common Political framework
 <img src="https://raw.githubusercontent.com/python-narrative/religionnlp/main/religion.jpg" width = "220" height = "100" 
alt="logo" align=center />

For detailed installation instructions, see the
[documentation](https://cpanlp.com/documentation).


```python
pip install religionnlp
import religionnlp as p
```


Check out: https://cpanlp.com